==> teapy-0.3.1.tar.gz: teapy-0.3.1/teapy/tests/test_expr.py <==
import numpy as np
import pandas as pd

import teapy as tp
from teapy.testing import assert_allclose


def test_slice():
    a = np.random.randn(100, 39)
    e = tp.Expr(a, copy=False)
    assert_allclose(e[:10, :].eview(), a[:10, :])
    assert_allclose(e[-4:9, :].eview(), a[-4:9, :])
    assert_allclose(e[:, -2:-4].eview(), a[:, -2:-4])
    assert_allclose(e[None, :, :].eview(), a[None, :, :])
    assert_allclose(e[[-3, -5], 3:9].eview(), a[[-3, -5], 3:9])
    e = tp.Expr(a, copy=True)
    assert_allclose(e.argsort(axis=1)[:, :10].eview(), a.argsort(axis=1)[:, :10])
    # # currentyly the logic is not the same
    # assert_allclose(e[[-3, -5], [3, -2]].eview(), a[[-3, -5], [3, -2]])

    a = np.array([1, 2, 3, 4, 5, 6, 7, 8])
    e = tp.Expr(a)
    assert e[-1].eview() == 8
    assert e[-3].eview() == 6
    assert_allclose(e[[-1, -2, -3, 1, 0]].eview(), a[[-1, -2, -3, 1, 0]])


def test_unique():
    assert_allclose(tp.Expr([1, 3, 2, 1, 2]).unique().eview(), [1, 3, 2])
    e = tp.Expr(["b", "bb", "a", "ab", "ab", "bb"]).unique()
    assert e.eview().tolist() == ["b", "bb", "a", "ab"]

    # test sorted unique
    a = tp.Expr([2, 2, 3, 3, 4, 5, 5])
    e1 = a._get_sorted_unique_idx("first").eview()
    assert_allclose(e1, [0, 2, 4, 5])
    e2 = a._get_sorted_unique_idx("last").eview()
    assert_allclose(e2, [1, 3, 4, 6])
    e3 = a.sorted_unique().eview()
    assert_allclose(e3, [2, 3, 4, 5])


def test_rolling():
    time = tp.Expr(
        pd.date_range("2020-01-01 04:00:00", "2020-01-5 00:00:00", freq="4H").values
    )
    value = tp.Expr(
        [5, 5, 9, 5, 8, 8, 2, 7, 3, 3, 8, 6, 4, 7, 8, 3, 1, 5, 3, 4, 4, 7, 9, 3]
    )
    res1 = value.rolling("12h", by=time).min().eval()
    expect1 = [5, 5, 5, 5, 5, 5, 2, 2, 2, 3, 3, 3, 4, 4, 4, 3, 1, 1, 1, 3, 3, 4, 4, 3]
    assert_allclose(res1.view, expect1)
    res2 = value.rolling("12h", by=time, start_by="duration_start").min().eval()
    expect2 = [5, 5, 9, 5, 5, 8, 2, 2, 3, 3, 3, 6, 4, 4, 8, 3, 1, 5, 3, 3, 4, 4, 4, 3]
    assert_allclose(res2.view, expect2)

    time = tp.Expr(pd.date_range("2020-01-01", "2020-05-05", freq="8d").values)
    value = tp.Expr([1, 9, 3, 1, 5, 4, 3, 8, 1, 1, 5, 2, 6, 8, 7, 9])
    res3 = value.rolling("1mo", by=time).min().eval()
    expect3 = [1, 1, 1, 1, 1, 1, 1, 3, 1, 1, 1, 1, 1, 2, 2, 6]
    assert_allclose(res3.view, expect3)
    res4 = value.rolling("1mo", by=time, start_by="duration_start").max().eval()
    expect4 = [1, 9, 9, 9, 5, 5, 5, 8, 1, 1, 5, 5, 6, 8, 8, 9]
    assert_allclose(res4.view, expect4)

==> teapy-0.3.2.tar.gz: teapy-0.3.2/teapy/tests/test_expr.py <==
import numpy as np
import pandas as pd

import teapy as tp
from teapy.testing import assert_allclose


def test_slice():
    a = np.random.randn(100, 39)
    e = tp.Expr(a, copy=False)
    assert_allclose(e[:10, :].eview(), a[:10, :])
    assert_allclose(e[-4:9, :].eview(), a[-4:9, :])
    assert_allclose(e[:, -2:-4].eview(), a[:, -2:-4])
    assert_allclose(e[None, :, :].eview(), a[None, :, :])
    assert_allclose(e[[-3, -5], 3:9].eview(), a[[-3, -5], 3:9])
    e = tp.Expr(a, copy=True)
    assert_allclose(e.argsort(axis=1)[:, :10].eview(), a.argsort(axis=1)[:, :10])
    # # currentyly the logic is not the same
    # assert_allclose(e[[-3, -5], [3, -2]].eview(), a[[-3, -5], [3, -2]])

    a = np.array([1, 2, 3, 4, 5, 6, 7, 8])
    e = tp.Expr(a)
    assert e[-1].eview() == 8
    assert e[-3].eview() == 6
    assert_allclose(e[[-1, -2, -3, 1, 0]].eview(), a[[-1, -2, -3, 1, 0]])


def test_unique():
    assert_allclose(tp.Expr([1, 3, 2, 1, 2]).unique().eview(), [1, 3, 2])
    e = tp.Expr(["b", "bb", "a", "ab", "ab", "bb"]).unique()
    assert e.eview().tolist() == ["b", "bb", "a", "ab"]

    # test sorted unique
    a = tp.Expr([2, 2, 3, 3, 4, 5, 5])
    e1 = a._get_sorted_unique_idx("first").eview()
    assert_allclose(e1, [0, 2, 4, 5])
    e2 = a._get_sorted_unique_idx("last").eview()
    assert_allclose(e2, [1, 3, 4, 6])
    e3 = a.sorted_unique().eview()
    assert_allclose(e3, [2, 3, 4, 5])


def test_rolling():
    time = tp.Expr(
        pd.date_range("2020-01-01 04:00:00", "2020-01-5 00:00:00", freq="4H").values
    )
    value = tp.Expr(
        [5, 5, 9, 5, 8, 8, 2, 7, 3, 3, 8, 6, 4, 7, 8, 3, 1, 5, 3, 4, 4, 7, 9, 3]
    )
    res1 = value.rolling("12h", by=time).min().eval()
    expect1 = [5, 5, 5, 5, 5, 5, 2, 2, 2, 3, 3, 3, 4, 4, 4, 3, 1, 1, 1, 3, 3, 4, 4, 3]
    assert_allclose(res1.view, expect1)
    res2 = value.rolling("12h", by=time, start_by="duration_start").min().eval()
    expect2 = [5, 5, 9, 5, 5, 8, 2, 2, 3, 3, 3, 6, 4, 4, 8, 3, 1, 5, 3, 3, 4, 4, 4, 3]
    assert_allclose(res2.view, expect2)
    res3 = value.rolling(by=time, window="3d", offset="1d").sum().eval()
    expect3 = [
        5,
        5,
        9,
        5,
        8,
        8,
        7,
        12,
        12,
        8,
        16,
        14,
        11,
        19,
        20,
        11,
        17,
        19,
        14,
        23,
        24,
        18,
        26,
        22,
    ]
    assert_allclose(res3.view, expect3)

    time = tp.Expr(pd.date_range("2020-01-01", "2020-05-05", freq="8d").values)
    value = tp.Expr([1, 9, 3, 1, 5, 4, 3, 8, 1, 1, 5, 2, 6, 8, 7, 9])
    res4 = value.rolling("1mo", by=time).min().eval()
    expect4 = [1, 1, 1, 1, 1, 1, 1, 3, 1, 1, 1, 1, 1, 2, 2, 6]
    assert_allclose(res4.view, expect4)
    res5 = value.rolling("1mo", by=time, start_by="duration_start").max().eval()
    expect5 = [1, 9, 9, 9, 5, 5, 5, 8, 1, 1, 5, 5, 6, 8, 8, 9]
    assert_allclose(res5.view, expect5)
